@@ -41,69 +41,69 @@
 #define KD4GroupEffect    "E"
 
 // Channels
-#define KD4TagFixture   "Fixture"
-#define KD4TagName      "Name"
-#define KD4TagShortName "ShortName"
-#define KD4TagCompany   "Company"
-#define KD4TagControl   "Control"
-#define KD4TagID        "ID"
-#define KD4TagGroup     "Group"
-#define KD4TagSpeed     "Speed"
-#define KD4TagMacro     "Macro"
-#define KD4TagReserved  "Reserved"
-#define KD4TagShutter   "Shutter"
-#define KD4TagPan       "Pan"
-#define KD4TagTilt      "Tilt"
-#define KD4TagCyan      "Cyan"
-#define KD4TagMagenta   "Magenta"
-#define KD4TagYellow    "Yellow"
-#define KD4TagRed       "Red"
-#define KD4TagBlue      "Blue"
-#define KD4TagGreen     "Green"
-#define KD4TagPrism     "Prism"
-#define KD4TagEffect    "Effect"
-#define KD4TagAttribute "Attribute"
-#define KD4TagUpdate    "Update"
+#define KD4TagFixture   QString("Fixture")
+#define KD4TagName      QString("Name")
+#define KD4TagShortName QString("ShortName")
+#define KD4TagCompany   QString("Company")
+#define KD4TagControl   QString("Control")
+#define KD4TagID        QString("ID")
+#define KD4TagGroup     QString("Group")
+#define KD4TagSpeed     QString("Speed")
+#define KD4TagMacro     QString("Macro")
+#define KD4TagReserved  QString("Reserved")
+#define KD4TagShutter   QString("Shutter")
+#define KD4TagPan       QString("Pan")
+#define KD4TagTilt      QString("Tilt")
+#define KD4TagCyan      QString("Cyan")
+#define KD4TagMagenta   QString("Magenta")
+#define KD4TagYellow    QString("Yellow")
+#define KD4TagRed       QString("Red")
+#define KD4TagBlue      QString("Blue")
+#define KD4TagGreen     QString("Green")
+#define KD4TagPrism     QString("Prism")
+#define KD4TagEffect    QString("Effect")
+#define KD4TagAttribute QString("Attribute")
+#define KD4TagUpdate    QString("Update")
 
 // Capabilities
-#define KD4TagFunction                  "Function"
-#define KD4TagFunctionName              "Name"
-#define KD4TagFunctionDmx               "Dmx"
+#define KD4TagFunction                  QString("Function")
+#define KD4TagFunctionName              QString("Name")
+#define KD4TagFunctionDmx               QString("Dmx")
 #define KD4TagFunctionDmxValueSeparator '~'
 
 // Mode section
-#define KD4TagMode                 "Mode"
-#define KD4TagModeName             "Name"
-#define KD4TagModeInclude          "Include"
-#define KD4TagModeAttribute        "Attribute"
-#define KD4TagModeChannelOffset    "ChannelOffset"
-#define KD4TagModeID               "ID"
+#define KD4TagMode                 QString("Mode")
+#define KD4TagModeName             QString("Name")
+#define KD4TagModeInclude          QString("Include")
+#define KD4TagModeAttribute        QString("Attribute")
+#define KD4TagModeChannelOffset    QString("ChannelOffset")
+#define KD4TagModeID               QString("ID")
 #define KD4TagModeChannelSeparator ','
 
 // Palettes section
-#define KD4TagPalettes          "Palettes"
-#define KD4TagPalette           "Palette"
+#define KD4TagPalettes          QString("Palettes")
+#define KD4TagPalette           QString("Palette")
 
 // Physical section
-#define KD4TagPhysical                     "Physical"
-#define KD4TagPhysicalBulb                 "Bulb"
-#define KD4TagPhysicalBulbType             "Type"
-#define KD4TagPhysicalBulbLumens           "Lumens"
-#define KD4TagPhysicalBulbColourTemp       "ColourTemp"
-#define KD4TagPhysicalLens                 "Lens"
-#define KD4TagPhysicalLensName             "Name"
-#define KD4TagPhysicalLensDegrees          "Degrees"
-#define KD4TagPhysicalLensDegreesSeparator '~'
-#define KD4TagPhysicalWeight               "Weight"
-#define KD4TagPhysicalWeightKg             "Kg"
-#define KD4TagPhysicalSize                 "Size"
-#define KD4TagPhysicalSizeHeight           "Height"
-#define KD4TagPhysicalSizeWidth            "Width"
-#define KD4TagPhysicalSizeDepth            "Depth"
-#define KD4TagPhysicalFocus                "Focus"
-#define KD4TagPhysicalFocusType            "Type"
-#define KD4TagPhysicalFocusPanMax          "PanMax"
-#define KD4TagPhysicalFocusTiltMax         "TiltMax"
+#define KD4TagPhysical                     QString("Physical")
+#define KD4TagPhysicalBulb                 QString("Bulb")
+#define KD4TagPhysicalBulbType             QString("Type")
+#define KD4TagPhysicalBulbLumens           QString("Lumens")
+#define KD4TagPhysicalBulbColourTemp       QString("ColourTemp")
+#define KD4TagPhysicalLens                 QString("Lens")
+#define KD4TagPhysicalLensName             QString("Name")
+#define KD4TagPhysicalLensDegrees          QString("Degrees")
+#define KD4TagPhysicalLensDegreesSeparator QString('~')
+#define KD4TagPhysicalWeight               QString("Weight")
+#define KD4TagPhysicalWeightKg             QString("Kg")
+#define KD4TagPhysicalSize                 QString("Size")
+#define KD4TagPhysicalSizeHeight           QString("Height")
+#define KD4TagPhysicalSizeWidth            QString("Width")
+#define KD4TagPhysicalSizeDepth            QString("Depth")
+#define KD4TagPhysicalFocus                QString("Focus")
+#define KD4TagPhysicalFocusType            QString("Type")
+#define KD4TagPhysicalFocusPanMax          QString("PanMax")
+#define KD4TagPhysicalFocusTiltMax         QString("TiltMax")
 
 // Static attibute map shared between instances of the parser, initialized only
 // once per application.
