@@ -42,6 +42,8 @@
 #define KXMLQLCChaserSpeedModePerStep "PerStep"
 #define KXMLQLCChaserSpeedModeDefault "Default"
 
+#define KXMLQLCChaserLegacySequence QString("Sequence")
+
 /*****************************************************************************
  * Initialization
  *****************************************************************************/
@@ -438,7 +440,7 @@ bool Chaser::loadXML(QXmlStreamReader &root)
                     m_steps.insert(stepNumber, step);
             }
         }
-        else if (root.name() == "Sequence")
+        else if (root.name() == KXMLQLCChaserLegacySequence)
         {
             doc()->appendToErrorLog(QString("<b>Unsupported sequences found</b>. Please convert your project "
                                             "at <a href=http://www.qlcplus.org/sequence_migration.php>http://www.qlcplus.org/sequence_migration.php</a>"));
@@ -637,15 +639,27 @@ void Chaser::setPause(bool enable)
 {
     QMutexLocker runnerLocker(&m_runnerMutex);
     if (m_runner != NULL)
-        m_runner->setPause(enable);
+    {
+        // request a change of pause state at the next write call
+        m_startupAction.m_action = ChaserPauseRequest;
+        // use fade mode to pass through enable/disable flag
+        m_startupAction.m_fadeMode = enable ? 1 : 0;
+    }
     Function::setPause(enable);
 }
 
 void Chaser::write(MasterTimer* timer, QList<Universe *> universes)
 {
-    if (isPaused())
+    if (isPaused() && m_startupAction.m_action != ChaserPauseRequest)
         return;
 
+    if (m_startupAction.m_action == ChaserPauseRequest)
+    {
+        qDebug() << "[Chaser] Request PAUSE" << m_startupAction.m_fadeMode;
+        m_runner->setAction(m_startupAction);
+        m_startupAction.m_action = ChaserNoAction;
+    }
+
     {
         QMutexLocker runnerLocker(&m_runnerMutex);
         QMutexLocker stepListLocker(&m_stepListMutex);
@@ -663,6 +677,10 @@ void Chaser::postRun(MasterTimer* timer, QList<Universe *> universes)
     {
         QMutexLocker runnerLocker(&m_runnerMutex);
         Q_ASSERT(m_runner != NULL);
+
+        if (isPaused())
+            m_runner->setPause(false, universes);
+
         m_runner->postRun(timer, universes);
 
         delete m_runner;
