@@ -500,6 +500,13 @@ public:
      */
     QList <Function*> functionsByType(Function::Type type) const;
 
+    /**
+     * Get a pointer to a Function with the given name
+     * @param name lookup Function name
+     * @return pointer to Function or null if not found
+     */
+    Function *functionByName(QString name);
+
     /**
      * Delete the given function
      *
