@@ -31,6 +31,7 @@
 #include "qlcfixturedef.h"
 #include "qlccapability.h"
 #include "qlcchannel.h"
+#include "qlcfile.h"
 
 #include "fixture.h"
 #include "doc.h"
@@ -385,6 +386,48 @@ QList<SceneValue> Fixture::positionToValues(int type, int degrees) const
     return posList;
 }
 
+QList<SceneValue> Fixture::zoomToValues(float degrees) const
+{
+    QList<SceneValue> chList;
+
+    if (m_fixtureMode == NULL)
+        return chList;
+
+    QLCPhysical phy = fixtureMode()->physical();
+    float msbValue = ((degrees - phy.lensDegreesMin()) * (float)UCHAR_MAX) /
+                     (phy.lensDegreesMax() - phy.lensDegreesMin());
+
+    for (quint32 i = 0; i < quint32(m_fixtureMode->channels().size()); i++)
+    {
+        const QLCChannel *ch = m_fixtureMode->channel(i);
+
+        if (ch->group() != QLCChannel::Beam)
+            continue;
+
+        if (ch->preset() != QLCChannel::BeamZoomBigSmall &&
+            ch->preset() != QLCChannel::BeamZoomSmallBig &&
+            ch->preset() != QLCChannel::BeamZoomFine)
+            continue;
+
+        if (ch->controlByte() == QLCChannel::MSB)
+        {
+            if (ch->preset() == QLCChannel::BeamZoomBigSmall)
+                chList.append(SceneValue(id(), i, static_cast<uchar>(qFloor((float)UCHAR_MAX - msbValue))));
+            else
+                chList.append(SceneValue(id(), i, static_cast<uchar>(qFloor(msbValue))));
+        }
+
+        if (ch->controlByte() == QLCChannel::LSB)
+        {
+            float lsbDegrees = (float)(phy.lensDegreesMax() - phy.lensDegreesMin()) / (float)UCHAR_MAX;
+            float lsbValue = (float)((msbValue - qFloor(msbValue)) * (float)UCHAR_MAX) / lsbDegrees;
+            chList.append(SceneValue(id(), i, static_cast<uchar>(lsbValue)));
+        }
+    }
+
+    return chList;
+}
+
 void Fixture::setExcludeFadeChannels(QList<int> indices)
 {
     if (indices.count() > (int)channels())
@@ -922,7 +965,7 @@ bool Fixture::loader(QXmlStreamReader &root, Doc* doc)
 }
 
 bool Fixture::loadXML(QXmlStreamReader &xmlDoc, Doc *doc,
-                      const QLCFixtureDefCache* fixtureDefCache)
+                      QLCFixtureDefCache *fixtureDefCache)
 {
     QLCFixtureDef* fixtureDef = NULL;
     QLCFixtureMode* fixtureMode = NULL;
@@ -1043,11 +1086,27 @@ bool Fixture::loadXML(QXmlStreamReader &xmlDoc, Doc *doc,
         fixtureDef = fixtureDefCache->fixtureDef(manufacturer, model);
         if (fixtureDef == NULL)
         {
-            doc->appendToErrorLog(QString("No fixture definition found for <b>%1</b> <b>%2</b>")
-                                  .arg(manufacturer)
-                                  .arg(model));
+            // fallback to project local path
+            QString man(manufacturer);
+            QString mod(model);
+            QString path = QString("%1%2%3-%4%5")
+                    .arg(doc->getWorkspacePath()).arg(QDir::separator())
+                    .arg(man.replace(" ", "-")).arg(mod.replace(" ", "-")).arg(KExtFixture);
+
+            qDebug() << "Fixture not found. Fallback to:" << path;
+
+            if (fixtureDefCache->loadQXF(path, true) == false)
+                qDebug() << "Failed to load definition" << path;
+
+            fixtureDef = fixtureDefCache->fixtureDef(manufacturer, model);
+            if (fixtureDef == NULL)
+            {
+                doc->appendToErrorLog(QString("No fixture definition found for <b>%1</b> <b>%2</b>")
+                                      .arg(manufacturer).arg(model));
+            }
         }
-        else
+
+        if (fixtureDef != NULL)
         {
             /* Find the given fixture mode */
             fixtureMode = fixtureDef->mode(modeName);
