@@ -238,27 +238,27 @@
         <translation>%1 - Cercador de documents</translation>
     </message>
     <message>
-        <location filename="../ui/src/docbrowser.cpp" line="124"/>
+        <location filename="../ui/src/docbrowser.cpp" line="127"/>
         <source>Backward</source>
         <translation>Enrere</translation>
     </message>
     <message>
-        <location filename="../ui/src/docbrowser.cpp" line="125"/>
+        <location filename="../ui/src/docbrowser.cpp" line="128"/>
         <source>Forward</source>
         <translation>Endavant</translation>
     </message>
     <message>
-        <location filename="../ui/src/docbrowser.cpp" line="126"/>
+        <location filename="../ui/src/docbrowser.cpp" line="129"/>
         <source>Index</source>
         <translation>Índex</translation>
     </message>
     <message>
-        <location filename="../ui/src/docbrowser.cpp" line="127"/>
+        <location filename="../ui/src/docbrowser.cpp" line="130"/>
         <source>About Qt</source>
         <translation>Quant a QT</translation>
     </message>
     <message>
-        <location filename="../ui/src/docbrowser.cpp" line="128"/>
+        <location filename="../ui/src/docbrowser.cpp" line="131"/>
         <source>Close this window</source>
         <translation>Tanca aquesta finestra</translation>
     </message>
@@ -358,19 +358,19 @@
     </message>
     <message>
         <location filename="editchannel.ui" line="90"/>
-        <location filename="editchannel.cpp" line="574"/>
+        <location filename="editchannel.cpp" line="572"/>
         <source>Minimum value</source>
         <translation>Valor Mínim</translation>
     </message>
     <message>
         <location filename="editchannel.ui" line="95"/>
-        <location filename="editchannel.cpp" line="574"/>
+        <location filename="editchannel.cpp" line="572"/>
         <source>Maximum value</source>
         <translation>Valor Màxim</translation>
     </message>
     <message>
         <location filename="editchannel.ui" line="100"/>
-        <location filename="editchannel.cpp" line="574"/>
+        <location filename="editchannel.cpp" line="572"/>
         <source>Description</source>
         <translation>Descripció</translation>
     </message>
@@ -390,34 +390,34 @@
         <translation>Editar Canal:</translation>
     </message>
     <message>
-        <location filename="editchannel.cpp" line="483"/>
+        <location filename="editchannel.cpp" line="481"/>
         <source>Overlapping values</source>
         <translation>Superposició de Valors</translation>
     </message>
     <message>
-        <location filename="editchannel.cpp" line="500"/>
+        <location filename="editchannel.cpp" line="498"/>
         <source>Open Gobo File</source>
         <translation>Obrir arxiu de Gobo</translation>
     </message>
     <message>
-        <location filename="editchannel.cpp" line="503"/>
+        <location filename="editchannel.cpp" line="501"/>
         <source>Gobo pictures</source>
         <translation>Imatges de gobo</translation>
     </message>
     <message>
-        <location filename="editchannel.cpp" line="619"/>
+        <location filename="editchannel.cpp" line="615"/>
         <source>Missing resources</source>
         <translation>Recursos que falten</translation>
     </message>
     <message>
-        <location filename="editchannel.cpp" line="620"/>
+        <location filename="editchannel.cpp" line="616"/>
         <source>Some gobos are missing:
 
 </source>
         <translation>Alguns gobos falten:</translation>
     </message>
     <message>
-        <location filename="editchannel.cpp" line="484"/>
+        <location filename="editchannel.cpp" line="482"/>
         <source>Some capabilities could not be created because of overlapping values.</source>
         <translation>Algunes capacitats no poden ser creades degut a una superposició de valors.</translation>
     </message>
@@ -541,130 +541,131 @@
 <context>
     <name>EditPhysical</name>
     <message>
-        <location filename="editphysical.ui" line="234"/>
+        <location filename="editphysical.ui" line="277"/>
         <source>Bulb</source>
         <translation>Bombeta</translation>
     </message>
     <message>
-        <location filename="editphysical.ui" line="240"/>
-        <location filename="editphysical.ui" line="593"/>
+        <location filename="editphysical.ui" line="45"/>
+        <location filename="editphysical.ui" line="283"/>
         <source>Type</source>
         <translation>Tipus</translation>
     </message>
     <message>
-        <location filename="editphysical.ui" line="472"/>
+        <location filename="editphysical.ui" line="515"/>
         <source>Lumens</source>
         <translation>Lúmens</translation>
     </message>
     <message>
-        <location filename="editphysical.ui" line="492"/>
+        <location filename="editphysical.ui" line="535"/>
         <source>Colour Temp (K)</source>
         <translation>Temperatura de Color (K)</translation>
     </message>
     <message>
-        <location filename="editphysical.ui" line="39"/>
+        <location filename="editphysical.ui" line="708"/>
         <source>Dimensions</source>
         <translation>Dimensions</translation>
     </message>
     <message>
-        <location filename="editphysical.ui" line="45"/>
+        <location filename="editphysical.ui" line="784"/>
         <source>Weight</source>
         <translation>Pes</translation>
     </message>
     <message>
-        <location filename="editphysical.ui" line="52"/>
+        <location filename="editphysical.ui" line="714"/>
         <source>kg</source>
         <translation>kg</translation>
     </message>
     <message>
-        <location filename="editphysical.ui" line="62"/>
+        <location filename="editphysical.ui" line="724"/>
         <source>Width</source>
         <translation>Ample</translation>
     </message>
     <message>
-        <location filename="editphysical.ui" line="72"/>
-        <location filename="editphysical.ui" line="92"/>
-        <location filename="editphysical.ui" line="112"/>
+        <location filename="editphysical.ui" line="734"/>
+        <location filename="editphysical.ui" line="754"/>
+        <location filename="editphysical.ui" line="774"/>
         <source>mm</source>
         <translation>mm</translation>
     </message>
     <message>
-        <location filename="editphysical.ui" line="82"/>
+        <location filename="editphysical.ui" line="744"/>
         <source>Height</source>
         <translation>Alçada</translation>
     </message>
     <message>
-        <location filename="editphysical.ui" line="102"/>
+        <location filename="editphysical.ui" line="764"/>
         <source>Depth</source>
         <translation>Fondaria</translation>
     </message>
     <message>
-        <location filename="editphysical.ui" line="587"/>
+        <location filename="editphysical.ui" line="39"/>
         <source>Head(s)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="editphysical.ui" line="664"/>
+        <location filename="editphysical.ui" line="630"/>
         <source>Lens</source>
         <translation>Lents</translation>
     </message>
     <message>
-        <location filename="editphysical.ui" line="670"/>
+        <location filename="editphysical.ui" line="636"/>
         <source>Name</source>
         <translation>Nom</translation>
     </message>
     <message>
-        <location filename="editphysical.ui" line="699"/>
+        <location filename="editphysical.ui" line="665"/>
         <source>Min Degrees</source>
         <translation>Graus Mínims</translation>
     </message>
     <message>
-        <location filename="editphysical.ui" line="706"/>
+        <location filename="editphysical.ui" line="672"/>
         <source>Max Degrees</source>
         <translation>Graus Màxims</translation>
     </message>
     <message>
-        <location filename="editphysical.ui" line="739"/>
-        <source>Prism faces</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="editphysical.ui" line="627"/>
+        <location filename="editphysical.ui" line="79"/>
         <source>Pan Max Degrees</source>
         <translation>Graus Max de Pan</translation>
     </message>
     <message>
-        <location filename="editphysical.ui" line="644"/>
+        <location filename="editphysical.ui" line="96"/>
         <source>Tilt Max Degrees</source>
         <translation>Graus Max de Tilt</translation>
     </message>
     <message>
-        <location filename="editphysical.ui" line="125"/>
+        <location filename="editphysical.ui" line="113"/>
+        <source>Layout
+(Columns x Rows)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="editphysical.ui" line="158"/>
         <source>Electrical</source>
         <translation>Elèctric</translation>
     </message>
     <message>
-        <location filename="editphysical.ui" line="131"/>
+        <location filename="editphysical.ui" line="164"/>
         <source>Power Consumption</source>
         <translation>Consum elèctric</translation>
     </message>
     <message>
-        <location filename="editphysical.ui" line="141"/>
+        <location filename="editphysical.ui" line="174"/>
         <source>W</source>
         <translation>W</translation>
     </message>
     <message>
-        <location filename="editphysical.ui" line="151"/>
+        <location filename="editphysical.ui" line="184"/>
         <source>DMX Connector</source>
         <translation>Connector DMX</translation>
     </message>
     <message>
-        <location filename="editphysical.ui" line="198"/>
+        <location filename="editphysical.ui" line="241"/>
         <source>Copy physical information to clipboard</source>
         <translation>Copiar informació física al porta-retalls</translation>
     </message>
     <message>
-        <location filename="editphysical.ui" line="215"/>
+        <location filename="editphysical.ui" line="258"/>
         <source>Paste physical information from clipboard</source>
         <translation>Enganxar informació física del porta-retalls</translation>
     </message>
@@ -712,150 +713,160 @@
         <translation>El tipus general d&apos;aquest fixture</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.ui" line="229"/>
+        <location filename="fixtureeditor.ui" line="226"/>
+        <source>LED Bar (Beams)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="fixtureeditor.ui" line="235"/>
+        <source>LED Bar (Pixels)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="fixtureeditor.ui" line="247"/>
         <source>Author</source>
         <translation>Autor</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.ui" line="236"/>
+        <location filename="fixtureeditor.ui" line="254"/>
         <source>The name of the author of this fixture definition</source>
         <translation>Nom del autor d&apos;aquesta definició de fixture</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.ui" line="257"/>
-        <location filename="fixtureeditor.ui" line="457"/>
+        <location filename="fixtureeditor.ui" line="298"/>
+        <location filename="fixtureeditor.ui" line="498"/>
         <source>Channels</source>
         <translation>Canals</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.ui" line="279"/>
-        <location filename="fixtureeditor.ui" line="452"/>
+        <location filename="fixtureeditor.ui" line="320"/>
+        <location filename="fixtureeditor.ui" line="493"/>
         <source>Name</source>
         <translation>Nom</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.ui" line="284"/>
+        <location filename="fixtureeditor.ui" line="325"/>
         <source>Group</source>
         <translation>Grup</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.ui" line="292"/>
+        <location filename="fixtureeditor.ui" line="333"/>
         <source>Add a channel</source>
         <translation>Afegir un canal</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.ui" line="312"/>
+        <location filename="fixtureeditor.ui" line="353"/>
         <source>Remove the selected channel</source>
         <translation>Eliminar el canal seleccionat</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.ui" line="332"/>
+        <location filename="fixtureeditor.ui" line="373"/>
         <source>Edit the selected channel</source>
         <translation>Editar el canal seleccionat</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.ui" line="359"/>
+        <location filename="fixtureeditor.ui" line="400"/>
         <source>Copy the selected channel to the clipboard</source>
         <translation>Copiar el canal seleccionat al porta-retalls</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.ui" line="379"/>
+        <location filename="fixtureeditor.ui" line="420"/>
         <source>Paste the channel in clipboard to this fixture</source>
         <translation>Enganxar el canal del porta-retalls a aquest fixture</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.ui" line="412"/>
+        <location filename="fixtureeditor.ui" line="453"/>
         <source>Open/close all channel items</source>
         <translation>Obrir/Tancar tots els elements del canal</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.ui" line="433"/>
+        <location filename="fixtureeditor.ui" line="474"/>
         <source>Modes</source>
         <translation>Modes</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.ui" line="462"/>
+        <location filename="fixtureeditor.ui" line="503"/>
         <source>Heads</source>
         <translation>Capçals</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.ui" line="470"/>
+        <location filename="fixtureeditor.ui" line="511"/>
         <source>Add a mode</source>
         <translation>Afegir un mode</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.ui" line="490"/>
+        <location filename="fixtureeditor.ui" line="531"/>
         <source>Remove the selected mode</source>
         <translation>Eliminar el mode seleccionat</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.ui" line="510"/>
+        <location filename="fixtureeditor.ui" line="551"/>
         <source>Edit the selected mode</source>
         <translation>Editar el mode seleccionat</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.ui" line="537"/>
+        <location filename="fixtureeditor.ui" line="578"/>
         <source>Create a copy of the selected mode</source>
         <translation>Crear una copia del mode seleccionat</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.ui" line="570"/>
+        <location filename="fixtureeditor.ui" line="611"/>
         <source>Open/close all mode items</source>
         <translation>Obrir/Tancar tots els elements de mode</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.ui" line="591"/>
+        <location filename="fixtureeditor.ui" line="632"/>
         <source>Aliases</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="fixtureeditor.ui" line="609"/>
+        <location filename="fixtureeditor.ui" line="650"/>
         <source>In mode</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="fixtureeditor.ui" line="626"/>
+        <location filename="fixtureeditor.ui" line="667"/>
         <source>Add a new alias</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="fixtureeditor.ui" line="646"/>
+        <location filename="fixtureeditor.ui" line="687"/>
         <source>with</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="fixtureeditor.ui" line="653"/>
+        <location filename="fixtureeditor.ui" line="694"/>
         <source>replace</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="fixtureeditor.ui" line="670"/>
-        <location filename="fixtureeditor.ui" line="723"/>
+        <location filename="fixtureeditor.ui" line="711"/>
+        <location filename="fixtureeditor.ui" line="764"/>
         <source>Alias</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="fixtureeditor.ui" line="675"/>
+        <location filename="fixtureeditor.ui" line="716"/>
         <source>Mode</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="fixtureeditor.ui" line="680"/>
+        <location filename="fixtureeditor.ui" line="721"/>
         <source>Base channel</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="fixtureeditor.ui" line="685"/>
+        <location filename="fixtureeditor.ui" line="726"/>
         <source>Override channel</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="fixtureeditor.ui" line="703"/>
+        <location filename="fixtureeditor.ui" line="744"/>
         <source>Remove the currently selected alias</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="fixtureeditor.ui" line="736"/>
+        <location filename="fixtureeditor.ui" line="275"/>
         <source>Physical</source>
         <translation type="unfinished">Físic</translation>
     </message>
@@ -863,12 +874,12 @@
 <context>
     <name>QLCFixtureEditor</name>
     <message>
-        <location filename="fixtureeditor.cpp" line="206"/>
+        <location filename="fixtureeditor.cpp" line="207"/>
         <source>Close</source>
         <translation>Tancar</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.cpp" line="207"/>
+        <location filename="fixtureeditor.cpp" line="208"/>
         <source>Do you want to save changes to fixture
 &quot;%1&quot;
 before closing?</source>
@@ -877,167 +888,167 @@ before closing?</source>
 abans de tancar?</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.cpp" line="236"/>
-        <location filename="fixtureeditor.cpp" line="246"/>
+        <location filename="fixtureeditor.cpp" line="237"/>
+        <location filename="fixtureeditor.cpp" line="247"/>
         <source>Missing important information</source>
         <translation>Falta informació important</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.cpp" line="237"/>
+        <location filename="fixtureeditor.cpp" line="238"/>
         <source>Missing manufacturer name.
 Unable to save fixture.</source>
         <translation>Falta el nom del fabricant.
 No es  pot desar el fixture.</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.cpp" line="247"/>
+        <location filename="fixtureeditor.cpp" line="248"/>
         <source>Missing fixture model name.
 Unable to save fixture.</source>
         <translation>Falta el nom del model del fixture.
 No es pot desar el fixture.</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.cpp" line="277"/>
-        <location filename="fixtureeditor.cpp" line="336"/>
+        <location filename="fixtureeditor.cpp" line="278"/>
+        <location filename="fixtureeditor.cpp" line="337"/>
         <source>Fixture saving failed</source>
         <translation>Error al desar el fixture</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.cpp" line="278"/>
-        <location filename="fixtureeditor.cpp" line="337"/>
+        <location filename="fixtureeditor.cpp" line="279"/>
+        <location filename="fixtureeditor.cpp" line="338"/>
         <source>Unable to save fixture definition:
 %1</source>
         <translation>Imposible desar les definicions del fixture:
 %1</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.cpp" line="293"/>
+        <location filename="fixtureeditor.cpp" line="294"/>
         <source>Save fixture definition</source>
         <translation>Desar la definició del fixture</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.cpp" line="370"/>
+        <location filename="fixtureeditor.cpp" line="371"/>
         <source>New Fixture</source>
         <translation>Nou Fixture</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.cpp" line="447"/>
-        <location filename="fixtureeditor.cpp" line="533"/>
+        <location filename="fixtureeditor.cpp" line="448"/>
+        <location filename="fixtureeditor.cpp" line="534"/>
         <source>Channel already exists</source>
         <translation>El canal ja existeix</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.cpp" line="448"/>
-        <location filename="fixtureeditor.cpp" line="534"/>
+        <location filename="fixtureeditor.cpp" line="449"/>
+        <location filename="fixtureeditor.cpp" line="535"/>
         <source>A channel by the name &quot;%1&quot; already exists!</source>
         <translation>Un canal amb el nombre &quot;%1&quot; ja existeix!</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.cpp" line="455"/>
-        <location filename="fixtureeditor.cpp" line="540"/>
+        <location filename="fixtureeditor.cpp" line="456"/>
+        <location filename="fixtureeditor.cpp" line="541"/>
         <source>Channel has no name</source>
         <translation>El canal no te nom</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.cpp" line="456"/>
-        <location filename="fixtureeditor.cpp" line="541"/>
+        <location filename="fixtureeditor.cpp" line="457"/>
+        <location filename="fixtureeditor.cpp" line="542"/>
         <source>You must give the channel a descriptive name!</source>
         <translation>Te que donar un nom descriptiu al canal!</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.cpp" line="493"/>
+        <location filename="fixtureeditor.cpp" line="494"/>
         <source>Are you sure you wish to remove channel: %1?</source>
         <translation>Esteu segur que vol eliminar el canal: %1 ?</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.cpp" line="812"/>
+        <location filename="fixtureeditor.cpp" line="813"/>
         <source>Are you sure you wish to remove mode: %1?</source>
         <translation>Eteu segur que vol eliminar el mode: %1 ?</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.cpp" line="653"/>
-        <location filename="fixtureeditor.cpp" line="688"/>
-        <location filename="fixtureeditor.cpp" line="912"/>
+        <location filename="fixtureeditor.cpp" line="654"/>
+        <location filename="fixtureeditor.cpp" line="689"/>
+        <location filename="fixtureeditor.cpp" line="914"/>
         <source>Edit</source>
         <translation>Editar</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.cpp" line="654"/>
-        <location filename="fixtureeditor.cpp" line="690"/>
+        <location filename="fixtureeditor.cpp" line="655"/>
+        <location filename="fixtureeditor.cpp" line="691"/>
         <source>Copy</source>
         <translation>Copiar</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.cpp" line="655"/>
-        <location filename="fixtureeditor.cpp" line="692"/>
+        <location filename="fixtureeditor.cpp" line="656"/>
+        <location filename="fixtureeditor.cpp" line="693"/>
         <source>Paste</source>
         <translation>Enganxar</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.cpp" line="656"/>
-        <location filename="fixtureeditor.cpp" line="694"/>
-        <location filename="fixtureeditor.cpp" line="918"/>
+        <location filename="fixtureeditor.cpp" line="657"/>
+        <location filename="fixtureeditor.cpp" line="695"/>
+        <location filename="fixtureeditor.cpp" line="920"/>
         <source>Remove</source>
         <translation>Eliminar</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.cpp" line="667"/>
+        <location filename="fixtureeditor.cpp" line="668"/>
         <source>Channels</source>
         <translation>Canals</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.cpp" line="765"/>
-        <location filename="fixtureeditor.cpp" line="774"/>
+        <location filename="fixtureeditor.cpp" line="766"/>
+        <location filename="fixtureeditor.cpp" line="775"/>
         <source>Unable to add mode</source>
         <translation>Impossible afegir un mode</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.cpp" line="766"/>
+        <location filename="fixtureeditor.cpp" line="767"/>
         <source>Another mode by that name already exists</source>
         <translation>Un altre mode amb aquest nom ja existeix</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.cpp" line="775"/>
+        <location filename="fixtureeditor.cpp" line="776"/>
         <source>You must give a name to the mode</source>
         <translation>Necessita donar un nom al mode</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.cpp" line="811"/>
+        <location filename="fixtureeditor.cpp" line="812"/>
         <source>Remove Mode</source>
         <translation>Eliminar mode</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.cpp" line="858"/>
+        <location filename="fixtureeditor.cpp" line="860"/>
         <source>Rename new mode</source>
         <translation>Reanomenar el nou mode</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.cpp" line="859"/>
+        <location filename="fixtureeditor.cpp" line="861"/>
         <source>Give a unique name for the mode</source>
         <translation>Trieu un nom únic per el mode</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.cpp" line="861"/>
+        <location filename="fixtureeditor.cpp" line="863"/>
         <source>Copy of %1</source>
         <translation>Copia de %1</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.cpp" line="871"/>
+        <location filename="fixtureeditor.cpp" line="873"/>
         <source>Invalid name</source>
         <translation>Nom incorrecte</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.cpp" line="872"/>
+        <location filename="fixtureeditor.cpp" line="874"/>
         <source>Another mode by that name already exists.</source>
         <translation>Un altre mode amb aquest nom ja existeix.</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.cpp" line="915"/>
+        <location filename="fixtureeditor.cpp" line="917"/>
         <source>Clone</source>
         <translation>Clonar</translation>
     </message>
     <message>
-        <location filename="fixtureeditor.cpp" line="923"/>
+        <location filename="fixtureeditor.cpp" line="925"/>
         <source>Modes</source>
         <translation>Modes</translation>
     </message>
