@@ -143,11 +143,7 @@ QSharedPointer<QUdpSocket> E131Controller::getInputSocket(bool multicast, QHostA
 
     if (multicast)
     {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
         inputSocket->bind(QHostAddress::AnyIPv4, E131_DEFAULT_PORT, QUdpSocket::ShareAddress | QUdpSocket::ReuseAddressHint);
-#else
-        inputSocket->bind(QHostAddress::Any, E131_DEFAULT_PORT, QUdpSocket::ShareAddress | QUdpSocket::ReuseAddressHint);
-#endif
         inputSocket->joinMulticastGroup(address, m_interface);
     }
     else
@@ -401,8 +397,9 @@ void E131Controller::processPendingPackets()
 
         QByteArray dmxData;
         quint32 e131universe;
-        if (m_packetizer->checkPacket(datagram)
-                && m_packetizer->fillDMXdata(datagram, dmxData, e131universe))
+
+        if (m_packetizer->checkPacket(datagram) &&
+            m_packetizer->fillDMXdata(datagram, dmxData, e131universe))
         {
             qDebug() << "Received packet with size: " << datagram.size() << ", from: " << senderAddress.toString()
                 << ", for E1.31 universe: " << e131universe;
@@ -417,6 +414,7 @@ void E131Controller::processPendingPackets()
                     QByteArray *dmxValues;
                     if (m_dmxValuesMap.contains(universe) == false)
                         m_dmxValuesMap[universe] = new QByteArray(512, 0);
+
                     dmxValues = m_dmxValuesMap[universe];
 
                     for (int i = 0; i < dmxData.length(); i++)
