@@ -104,13 +104,13 @@ void ShowManager::setShowName(QString showName)
     emit showNameChanged(showName);
 }
 
-QList<Track *> ShowManager::tracks()
+QVariant ShowManager::tracks()
 {
     m_tracksList.clear();
     if (m_currentShow)
         m_tracksList = m_currentShow->tracks();
 
-    return m_tracksList;
+    return QVariant::fromValue(m_tracksList);
 }
 
 int ShowManager::selectedTrack() const
