@@ -154,11 +154,7 @@ void SceneEditor::slotSetSceneValues(QList <SceneValue>&sceneValues)
 
         FixtureConsole *fc = fixtureConsole(fixture);
         if (fc != NULL)
-        {
-            fc->blockSignals(true);
             fc->setSceneValue(sv);
-            fc->blockSignals(false);
-        }
     }
 }
 
@@ -338,6 +334,14 @@ void SceneEditor::init(bool applyValues)
     }
     connect(m_channelGroupsTree, SIGNAL(itemChanged(QTreeWidgetItem*,int)),
             this, SLOT(slotChannelGroupsChanged(QTreeWidgetItem*,int)));
+    connect(m_enableChannelsButton, SIGNAL(clicked()),
+            this, SLOT(slotEnableAll()));
+    connect(m_disableChannelsButton, SIGNAL(clicked()),
+            this, SLOT(slotDisableAll()));
+    connect(m_selectAllGroups, SIGNAL(clicked()),
+            this, SLOT(slotEnableAllChannelGroups()));
+    connect(m_deselectAllGroups, SIGNAL(clicked()),
+            this, SLOT(slotDisableAllChannelGroups()));
     updateChannelsGroupsTab();
 
     // Apply any mode related change
@@ -581,7 +585,7 @@ void SceneEditor::slotColorTool()
 {
     QColor color = slotColorSelectorChanged(QColor());
 
-    QColorDialog dialog(color);
+    QColorDialog dialog(color, this);
     connect(&dialog, SIGNAL(currentColorChanged(const QColor&)),
             this, SLOT(slotColorSelectorChanged(const QColor&)));
 
