@@ -1228,7 +1228,7 @@ void VCSlider::setTopLabelText(int value)
 
     if (valueDisplayStyle() == ExactValue)
     {
-        m_topLabel->setText(text.asprintf("%.3d", value));
+        text = text.asprintf("%.3d", value);
     }
     else
     {
@@ -1237,9 +1237,9 @@ void VCSlider::setTopLabelText(int value)
         if (m_slider)
             f = SCALE(float(value), float(m_slider->minimum()),
                       float(m_slider->maximum()), float(0), float(100));
-        m_topLabel->setText(text.asprintf("%.3d%%", static_cast<int> (f)));
+        text = text.asprintf("%.3d%%", static_cast<int> (f));
     }
-
+    m_topLabel->setText(text);
     emit valueChanged(text);
 }
 
